@@ -1,4 +1,4 @@
 from . import rbf
 from . import metrics
-from .localreg import localreg
+from .localreg import localreg, polyfit
 from .rbfnet import RBFnet, plot_corr
